Index: chrome/browser/ui/android/page_info/page_info_popup_android.h |
diff --git a/chrome/browser/ui/android/page_info/website_settings_popup_android.h b/chrome/browser/ui/android/page_info/page_info_popup_android.h |
similarity index 55% |
rename from chrome/browser/ui/android/page_info/website_settings_popup_android.h |
rename to chrome/browser/ui/android/page_info/page_info_popup_android.h |
index c7e2a0d57d458495ad8ae2a78289a10f55557bf8..e7b6c893e7f4369d1ed24b0ff680fd197846ec66 100644 |
--- a/chrome/browser/ui/android/page_info/website_settings_popup_android.h |
+++ b/chrome/browser/ui/android/page_info/page_info_popup_android.h |
@@ -2,8 +2,8 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef CHROME_BROWSER_UI_ANDROID_PAGE_INFO_WEBSITE_SETTINGS_POPUP_ANDROID_H_ |
-#define CHROME_BROWSER_UI_ANDROID_PAGE_INFO_WEBSITE_SETTINGS_POPUP_ANDROID_H_ |
+#ifndef CHROME_BROWSER_UI_ANDROID_PAGE_INFO_PAGE_INFO_POPUP_ANDROID_H_ |
+#define CHROME_BROWSER_UI_ANDROID_PAGE_INFO_PAGE_INFO_POPUP_ANDROID_H_ |
#include <jni.h> |
@@ -11,7 +11,7 @@ |
#include "base/android/scoped_java_ref.h" |
#include "base/macros.h" |
-#include "chrome/browser/ui/page_info/website_settings_ui.h" |
+#include "chrome/browser/ui/page_info/page_info_ui.h" |
namespace content { |
class WebContents; |
@@ -30,30 +30,29 @@ enum PageInfoConnectionType { |
CONNECTION_INTERNAL_PAGE, |
}; |
-// Android implementation of the website settings UI. |
-class WebsiteSettingsPopupAndroid : public WebsiteSettingsUI { |
+// Android implementation of the page info UI. |
+class PageInfoPopupAndroid : public PageInfoUI { |
public: |
- WebsiteSettingsPopupAndroid(JNIEnv* env, |
- jobject java_website_settings, |
- content::WebContents* web_contents); |
- ~WebsiteSettingsPopupAndroid() override; |
+ PageInfoPopupAndroid(JNIEnv* env, |
+ jobject java_page_info, |
+ content::WebContents* web_contents); |
+ ~PageInfoPopupAndroid() override; |
void Destroy(JNIEnv* env, const base::android::JavaParamRef<jobject>& obj); |
- void RecordWebsiteSettingsAction( |
- JNIEnv* env, |
- const base::android::JavaParamRef<jobject>& obj, |
- jint action); |
+ void RecordPageInfoAction(JNIEnv* env, |
+ const base::android::JavaParamRef<jobject>& obj, |
+ jint action); |
- // WebsiteSettingsUI implementations. |
+ // PageInfoUI implementations. |
void SetCookieInfo(const CookieInfoList& cookie_info_list) override; |
void SetPermissionInfo(const PermissionInfoList& permission_info_list, |
ChosenObjectInfoList chosen_object_info_list) override; |
void SetIdentityInfo(const IdentityInfo& identity_info) override; |
- static bool RegisterWebsiteSettingsPopupAndroid(JNIEnv* env); |
+ static bool RegisterPageInfoPopupAndroid(JNIEnv* env); |
private: |
- // The presenter that controlls the Website Settings UI. |
- std::unique_ptr<WebsiteSettings> presenter_; |
+ // The presenter that controlls the Page Info UI. |
+ std::unique_ptr<PageInfo> presenter_; |
// The java prompt implementation. |
base::android::ScopedJavaGlobalRef<jobject> popup_jobject_; |
@@ -63,7 +62,7 @@ class WebsiteSettingsPopupAndroid : public WebsiteSettingsUI { |
GURL url_; |
- DISALLOW_COPY_AND_ASSIGN(WebsiteSettingsPopupAndroid); |
+ DISALLOW_COPY_AND_ASSIGN(PageInfoPopupAndroid); |
}; |
-#endif // CHROME_BROWSER_UI_ANDROID_PAGE_INFO_WEBSITE_SETTINGS_POPUP_ANDROID_H_ |
+#endif // CHROME_BROWSER_UI_ANDROID_PAGE_INFO_PAGE_INFO_POPUP_ANDROID_H_ |